***************
Getting Started
***************

Here's a quick intro to get you started with the SDK.
See how you can:

* :doc:`Install the SDK <install>`,
* :doc:`Programmatically create, get and set properties of an AAS model <create_get_set>`,
* :doc:`Iterate over and transform a model <iterate_and_transform>`,
* :doc:`Verify a model <verify>`,
* :doc:`De/serialize a model from and to JSON <jsonize>`, and
* :doc:`De/serialize a model from and to XML <xmlize>`.

.. toctree::
   :maxdepth: 1

   install
   create_get_set
   iterate_and_transform
   verify
   jsonize
   xmlize
